google_api_sql_admin v0.33.0 GoogleApi.SQLAdmin.V1beta4.Model.BackupConfiguration View Source
Database instance backup configuration.
Attributes
-
binaryLogEnabled(type:boolean(), default:nil) - (MySQL only) Whether binary log is enabled. If backup configuration is disabled, binarylog must be disabled as well. -
enabled(type:boolean(), default:nil) - Whether this configuration is enabled. -
kind(type:String.t, default:nil) - This is always <b>sql#backupConfiguration</b>. -
location(type:String.t, default:nil) - Location of the backup -
pointInTimeRecoveryEnabled(type:boolean(), default:nil) - Reserved for future use. -
replicationLogArchivingEnabled(type:boolean(), default:nil) - Reserved for future use. -
startTime(type:String.t, default:nil) - Start time for the daily backup configuration in UTC timezone in the 24 hour format - <b>HH:MM</b>.
Link to this section Summary
Functions
Unwrap a decoded JSON object into its complex fields.
Link to this section Types
Specs
Link to this section Functions
Specs
Unwrap a decoded JSON object into its complex fields.