google_api_sql_admin v0.33.0 GoogleApi.SQLAdmin.V1beta4.Model.BackupRun View Source
A BackupRun resource.
Attributes
-
backupKind(type:String.t, default:nil) - Specifies the kind of backup, PHYSICAL or DEFAULT_SNAPSHOT. -
description(type:String.t, default:nil) - The description of this run, only applicable to on-demand backups. -
diskEncryptionConfiguration(type:GoogleApi.SQLAdmin.V1beta4.Model.DiskEncryptionConfiguration.t, default:nil) - Encryption configuration specific to a backup. Applies only to Second Generation instances. -
diskEncryptionStatus(type:GoogleApi.SQLAdmin.V1beta4.Model.DiskEncryptionStatus.t, default:nil) - Encryption status specific to a backup. Applies only to Second Generation instances. -
endTime(type:DateTime.t, default:nil) - The time the backup operation completed in UTC timezone in a href="https://tools.ietf.org/html/rfc3339"RFC 3339</a> format, for example <b>2012-11-15T16:19:00.094Z</b>. -
enqueuedTime(type:DateTime.t, default:nil) - The time the run was enqueued in UTC timezone in a href="https://tools.ietf.org/html/rfc3339"RFC 3339</a> format, for example <b>2012-11-15T16:19:00.094Z</b>. -
error(type:GoogleApi.SQLAdmin.V1beta4.Model.OperationError.t, default:nil) - Information about why the backup operation failed. This is only present if the run has the FAILED status. -
id(type:String.t, default:nil) - The identifier for this backup run. Unique only for a specific Cloud SQL instance. -
instance(type:String.t, default:nil) - Name of the database instance. -
kind(type:String.t, default:nil) - This is always <b>sql#backupRun</b>. -
location(type:String.t, default:nil) - Location of the backups. -
selfLink(type:String.t, default:nil) - The URI of this resource. -
startTime(type:DateTime.t, default:nil) - The time the backup operation actually started in UTC timezone in a href="https://tools.ietf.org/html/rfc3339"RFC 3339</a> format, for example <b>2012-11-15T16:19:00.094Z</b>. -
status(type:String.t, default:nil) - The status of this run. -
type(type:String.t, default:nil) - The type of this run; can be either "AUTOMATED" or "ON_DEMAND". -
windowStartTime(type:DateTime.t, default:nil) - The start time of the backup window during which this the backup was attempted in <a href="https://tools.ietf.org/html/rfc3339">RFC 3339</a> format, for example <b>2012-11-15T16:19:00.094Z</b>.
Link to this section Summary
Functions
Unwrap a decoded JSON object into its complex fields.
Link to this section Types
Specs
t() :: %GoogleApi.SQLAdmin.V1beta4.Model.BackupRun{
backupKind: String.t(),
description: String.t(),
diskEncryptionConfiguration:
GoogleApi.SQLAdmin.V1beta4.Model.DiskEncryptionConfiguration.t(),
diskEncryptionStatus:
GoogleApi.SQLAdmin.V1beta4.Model.DiskEncryptionStatus.t(),
endTime: DateTime.t(),
enqueuedTime: DateTime.t(),
error: GoogleApi.SQLAdmin.V1beta4.Model.OperationError.t(),
id: String.t(),
instance: String.t(),
kind: String.t(),
location: String.t(),
selfLink: String.t(),
startTime: DateTime.t(),
status: String.t(),
type: String.t(),
windowStartTime: DateTime.t()
}
Link to this section Functions
Specs
Unwrap a decoded JSON object into its complex fields.