google_api_sql_admin v0.33.0 GoogleApi.SQLAdmin.V1beta4.Model.ExportContext View Source
Database instance export context.
Attributes
-
csvExportOptions(type:GoogleApi.SQLAdmin.V1beta4.Model.ExportContextCsvExportOptions.t, default:nil) - Options for exporting data as CSV. -
databases(type:list(String.t), default:nil) - Databases to be exported. <br /> <b>MySQL instances:</b> If <b>fileType</b> is <b>SQL</b> and no database is specified, all databases are exported, except for the <b>mysql</b> system database. If <b>fileType</b> is <b>CSV</b>, you can specify one database, either by using this property or by using the <b>csvExportOptions.selectQuery</b> property, which takes precedence over this property. <br /> <b>PostgreSQL instances:</b> You must specify one database to be exported. If <b>fileType</b> is <b>CSV</b>, this database must match the one specified in the <b>csvExportOptions.selectQuery</b> property. -
fileType(type:String.t, default:nil) - The file type for the specified uri. <br><b>SQL</b>: The file contains SQL statements. <br><b>CSV</b>: The file contains CSV data. -
kind(type:String.t, default:nil) - This is always <b>sql#exportContext</b>. -
sqlExportOptions(type:GoogleApi.SQLAdmin.V1beta4.Model.ExportContextSqlExportOptions.t, default:nil) - Options for exporting data as SQL statements. -
uri(type:String.t, default:nil) - The path to the file in Google Cloud Storage where the export will be stored. The URI is in the form <b>gs: //bucketName/fileName</b>. If the file already exists, the requests // succeeds, but the operation fails. If <b>fileType</b> is // <b>SQL</b> and the filename ends with .gz, the contents are // compressed.
Link to this section Summary
Functions
Unwrap a decoded JSON object into its complex fields.
Link to this section Types
Specs
t() :: %GoogleApi.SQLAdmin.V1beta4.Model.ExportContext{
csvExportOptions:
GoogleApi.SQLAdmin.V1beta4.Model.ExportContextCsvExportOptions.t(),
databases: [String.t()],
fileType: String.t(),
kind: String.t(),
sqlExportOptions:
GoogleApi.SQLAdmin.V1beta4.Model.ExportContextSqlExportOptions.t(),
uri: String.t()
}
Link to this section Functions
Specs
Unwrap a decoded JSON object into its complex fields.