google_api_sql_admin v0.33.0 GoogleApi.SQLAdmin.V1beta4.Model.SslCert View Source
SslCerts Resource
Attributes
-
cert(type:String.t, default:nil) - PEM representation. -
certSerialNumber(type:String.t, default:nil) - Serial number, as extracted from the certificate. -
commonName(type:String.t, default:nil) - User supplied name. Constrained to [a-zA-Z.-_ ]+. -
createTime(type:DateTime.t, default:nil) - The time when the certificate was created in a href="https://tools.ietf.org/html/rfc3339"RFC 3339</a> format, for example <b>2012-11-15T16:19:00.094Z</b> -
expirationTime(type:DateTime.t, default:nil) - The time when the certificate expires in a href="https://tools.ietf.org/html/rfc3339"RFC 3339</a> format, for example <b>2012-11-15T16:19:00.094Z</b>. -
instance(type:String.t, default:nil) - Name of the database instance. -
kind(type:String.t, default:nil) - This is always <b>sql#sslCert</b>. -
selfLink(type:String.t, default:nil) - The URI of this resource. -
sha1Fingerprint(type:String.t, default:nil) - Sha1 Fingerprint.
Link to this section Summary
Functions
Unwrap a decoded JSON object into its complex fields.
Link to this section Types
Specs
t() :: %GoogleApi.SQLAdmin.V1beta4.Model.SslCert{
cert: String.t(),
certSerialNumber: String.t(),
commonName: String.t(),
createTime: DateTime.t(),
expirationTime: DateTime.t(),
instance: String.t(),
kind: String.t(),
selfLink: String.t(),
sha1Fingerprint: String.t()
}
Link to this section Functions
Specs
Unwrap a decoded JSON object into its complex fields.