google_api_sql_admin v0.33.0 GoogleApi.SQLAdmin.V1beta4.Model.User View Source
A Cloud SQL user resource.
Attributes
-
etag(type:String.t, default:nil) - This field is deprecated and will be removed from a future version of the API. -
host(type:String.t, default:nil) - The host name from which the user can connect. For <b>insert</b> operations, host defaults to an empty string. For <b>update</b> operations, host is specified as part of the request URL. The host name cannot be updated after insertion. -
instance(type:String.t, default:nil) - The name of the Cloud SQL instance. This does not include the project ID. Can be omitted for <b>update</b> since it is already specified on the URL. -
kind(type:String.t, default:nil) - This is always <b>sql#user</b>. -
name(type:String.t, default:nil) - The name of the user in the Cloud SQL instance. Can be omitted for <b>update</b> since it is already specified in the URL. -
password(type:String.t, default:nil) - The password for the user. -
project(type:String.t, default:nil) - The project ID of the project containing the Cloud SQL database. The Google apps domain is prefixed if applicable. Can be omitted for <b>update</b> since it is already specified on the URL. -
sqlserverUserDetails(type:GoogleApi.SQLAdmin.V1beta4.Model.SqlServerUserDetails.t, default:nil) -
Link to this section Summary
Functions
Unwrap a decoded JSON object into its complex fields.
Link to this section Types
Specs
Link to this section Functions
Specs
Unwrap a decoded JSON object into its complex fields.